#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.0
id: lrucache-1.2.0.0-97fd799690b7e95999ded6be87e87c88
key: lruca_LnEKhDbcc8GIMqzAA8165Q
license: BSD3
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
author: Carl Howells
exposed: True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.Internal Data.Cache.LRU.IO
    Data.Cache.LRU.IO.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/lrucache-1.2.0.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/lrucache-1.2.0.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/lrucache-1.2.0.0
hs-libraries: HSlrucache-1.2.0.0-LnEKhDbcc8GIMqzAA8165Q
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
